Package: statip
Type: Package
Title: Statistical Functions for Probability Distributions and
        Regression
Version: 0.2.3
Authors@R: c(person("Paul", "Poncet", , "paulponcet@yahoo.fr", role = c("aut", "cre")), 
    person("The R Core Team", role = c("aut", "cph"), 
           comment = "C function 'BinDist' copied from package 'stats'"), 
    person("The R Foundation", role = "cph", 
           comment = "C function 'BinDist' copied from package 'stats'"), 
    person("Adrian", "Baddeley", role = "ctb", 
           comment = "C function 'BinDist' copied from package 'stats'"))
Description: A collection of miscellaneous statistical functions for 
    probability distributions: 'dbern()', 'pbern()', 'qbern()', 'rbern()' for 
    the Bernoulli distribution, and 'distr2name()', 'name2distr()' for 
    distribution names; 
    probability density estimation: 'densityfun()'; 
    most frequent value estimation: 'mfv()', 'mfv1()'; 
    other statistical measures of location: 'cv()' (coefficient of variation),
    'midhinge()', 'midrange()', 'trimean()'; 
    construction of histograms: 'histo()', 'find_breaks()'; 
    calculation of the Hellinger distance: 'hellinger()'; 
    use of classical kernels: 'kernelfun()', 'kernel_properties()'; 
    univariate piecewise-constant regression: 'picor()'. 
License: GPL-3
LazyData: TRUE
Depends: R (>= 3.1.3)
Imports: clue, graphics, rpart, stats
Suggests: knitr, testthat
URL: https://github.com/paulponcet/statip
BugReports: https://github.com/paulponcet/statip/issues
RoxygenNote: 7.0.0
NeedsCompilation: yes
Packaged: 2019-11-17 21:21:11 UTC; YL1101
Author: Paul Poncet [aut, cre],
  The R Core Team [aut, cph] (C function 'BinDist' copied from package
    'stats'),
  The R Foundation [cph] (C function 'BinDist' copied from package
    'stats'),
  Adrian Baddeley [ctb] (C function 'BinDist' copied from package
    'stats')
Maintainer: Paul Poncet <paulponcet@yahoo.fr>
Repository: CRAN
Date/Publication: 2019-11-17 21:40:02 UTC
Built: R 4.6.0; aarch64-apple-darwin23; 2026-04-25 16:47:19 UTC; unix
Archs: statip.so.dSYM
