# Generated by roxygen2: do not edit by hand

S3method(as.stepfun,picor)
S3method(kernelfun,"function")
S3method(kernelfun,character)
S3method(knots,picor)
S3method(mfv,default)
S3method(mfv,tableNA)
S3method(plot,loess)
S3method(plot,picor)
S3method(predict,default)
S3method(predict,kmeans)
S3method(predict,picor)
S3method(print,picor)
export(.kernelsList)
export(as.stepfun)
export(bandwidth)
export(cv)
export(dbern)
export(densityfun)
export(distr2name)
export(erf)
export(find_breaks)
export(hellinger)
export(histo)
export(kernel_properties)
export(kernelfun)
export(knots)
export(lagk)
export(mfv)
export(mfv1)
export(midhinge)
export(midrange)
export(na.pass)
export(name2distr)
export(pbern)
export(picor)
export(plot)
export(predict)
export(qbern)
export(rbern)
export(tableNA)
export(trimean)
importFrom(clue,cl_predict)
importFrom(graphics,lines)
importFrom(graphics,plot)
importFrom(rpart,rpart)
importFrom(stats,IQR)
importFrom(stats,approxfun)
importFrom(stats,as.stepfun)
importFrom(stats,bw.SJ)
importFrom(stats,bw.bcv)
importFrom(stats,bw.nrd)
importFrom(stats,bw.nrd0)
importFrom(stats,bw.ucv)
importFrom(stats,fft)
importFrom(stats,integrate)
importFrom(stats,isoreg)
importFrom(stats,knots)
importFrom(stats,mad)
importFrom(stats,median)
importFrom(stats,model.frame)
importFrom(stats,na.pass)
importFrom(stats,pbinom)
importFrom(stats,pnorm)
importFrom(stats,predict)
importFrom(stats,qbinom)
importFrom(stats,quantile)
importFrom(stats,sd)
importFrom(stats,stepfun)
importFrom(stats,var)
useDynLib(statip, .registration=TRUE)
useDynLib(statip,BinDist)
