# statip: miscellaneous statistical functions

[![Travis-CI Build Status](https://travis-ci.org/paulponcet/statip.svg?branch=master)](https://travis-ci.org/paulponcet/statip) [![CRAN_Status_Badge](http://www.r-pkg.org/badges/version/statip)](https://cran.r-project.org/package=statip) [![](https://cranlogs.r-pkg.org/badges/statip)](https://cran.r-project.org/package=statip)

A collection of miscellaneous statistical functions for 
probability distributions: dbern(), pbern(), qbern(), rbern() for 
the Bernoulli distribution, and distr2name(), name2distr() for 
distribution names; 
probability density estimation: densityfun(); 
most frequent value estimation: mfv(), mfv1(); 
calculation of the Hellinger distance: hellinger(); 
use of classical kernels: kernelfun(), kernel_properties().


## Installation

You can install 'statip' from GitHub with:

```R
# install.packages("devtools")
devtools::install_github("paulponcet/statip")
```
