
#' @export
#' @rdname kernelfun
#' 
.kernelsList <- function() {
  c("biweight",
    "chernoff",
    "cosine",
    "eddy",
    "epanechnikov",
    "gaussian",
    "optcosine",
    "rectangular",
    "triangular",
    "uniform")
}
